==> haskell-wai-logger-2.3.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.0
id: wai-logger-2.3.0-EZQMUMTGcl9LAjZygwoAoH
key: wai-logger-2.3.0-EZQMUMTGcl9LAjZygwoAoH
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: 3f9fdc7b49f6cda804ee0be9a40fe555
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-logger-2.3.0
hs-libraries: HSwai-logger-2.3.0-EZQMUMTGcl9LAjZygwoAoH
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.3.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.0
id: wai-logger-2.3.0-DDgTghbN3V68n0QwzrUedI
key: wai-logger-2.3.0-DDgTghbN3V68n0QwzrUedI
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: a5d7e2d03a2c31adf897535ea425c0c6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-logger-2.3.0
hs-libraries: HSwai-logger-2.3.0-DDgTghbN3V68n0QwzrUedI
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG unix-2.7.2.0
    unix-time-0.3.7-HcxGsrnTmTlC98pyanzoMW
    wai-3.2.1.1-1k6hSu2jHMHEfd9vQlBLrn
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
